pub unsafe extern "C" fn ob_create_frameset(
error: *mut *mut ob_error,
) -> *mut ob_frameExpand description
@brief Create an empty frameset object. @brief A frameset object is a special type of frame object that can be used to store multiple frames.
@attention The frameset object is created with a reference count of 1, and the reference count should be decreased by calling @ref ob_delete_frame() when it is no longer needed.
@param[out] error Pointer to an error object that will be set if an error occurs. @return ob_frame* Return the frameset object.