ob_create_record_device

Function ob_create_record_device 

pub unsafe extern "C" fn ob_create_record_device(
    device: *mut ob_device,
    file_path: *const c_char,
    compression_enabled: bool,
    error: *mut *mut ob_error,
) -> *mut ob_record_device
@brief Create a recording device for the specified device with a specified file path and compression enabled.

@param[in] device The device to record. @param[in] file_path The file path to record to. @param[in] compression_enabled Whether to enable compression for the recording. @param[out] error Pointer to an error object that will be set if an error occurs. @return A pointer to the newly created recording device, or NULL if an error occurred.