ob_delete_context

Function ob_delete_context 

pub unsafe extern "C" fn ob_delete_context(
    context: *mut ob_context,
    error: *mut *mut ob_error,
)
@brief Delete a context object

@param[in] context Pointer to the context object to be deleted @param[out] error Pointer to an error object that will be populated if an error occurs during context deletion