pub unsafe extern "C" fn ob_device_set_structured_data(
device: *mut ob_device,
property_id: ob_property_id,
data: *const u8,
data_size: u32,
error: *mut *mut ob_error,
)Expand description
@brief Set structured data.
@param[in] device The device object. @param[in] property_id The ID of the property to be set. @param[in] data The property data to be set. @param[in] data_size The size of the property to be set. @param[out] error Pointer to an error object that will be set if an error occurs.