ob_device_timer_sync_with_host

Function ob_device_timer_sync_with_host 

pub unsafe extern "C" fn ob_device_timer_sync_with_host(
    device: *mut ob_device,
    error: *mut *mut ob_error,
)
@brief synchronize the timer of the device with the host. @brief After calling this function, the timer of the device will be synchronized with the host. User can call this function to multiple devices to synchronize all timers of the devices.

@attention If the stream of the device is started, the timestamp of the continuous frames output by the stream will may jump once after the timer sync. @attention Due to the timer of device is not high-accuracy, the timestamp of the continuous frames output by the stream will drift after a long time. User can call this function periodically to synchronize the timer to avoid the timestamp drift, the recommended interval time is 60 minutes.

@param[in] device The device handle. @param[out] error Pointer to an error object that will be set if an error occurs.