ob_enable_device_clock_sync

Function ob_enable_device_clock_sync 

pub unsafe extern "C" fn ob_enable_device_clock_sync(
    context: *mut ob_context,
    repeat_interval_msec: u64,
    error: *mut *mut ob_error,
)
@brief Activates device clock synchronization to synchronize the clock of the host and all created devices (if supported).

@param[in] context Pointer to the context object @param[in] repeat_interval_msec The interval for auto-repeated synchronization, in milliseconds. If the value is 0, synchronization is performed only once. @param[out] error Pointer to an error object that will be populated if an error occurs during execution