pub unsafe extern "C" fn ob_frame_get_data(
frame: *const ob_frame,
error: *mut *mut ob_error,
) -> *mut u8Expand description
@brief Get the data buffer of a frame.
@attention The returned data buffer is mutable, but it is not recommended to modify it directly. Modifying the data directly may cause issues if the frame is being used in other threads or future use. If you need to modify the data, it is recommended to create a new frame object.
@param[in] frame The frame object from which to retrieve the data. @param[out] error Pointer to an error object that will be set if an error occurs. @return uint8_t* Pointer to the frame data buffer.