#[repr(C, packed(1))]pub struct ob_error {
pub status: ob_status,
pub message: [c_char; 256],
pub function: [c_char; 256],
pub args: [c_char; 256],
pub exception_type: ob_exception_type,
}Expand description
@brief The error class exposed by the SDK, users can get detailed error information according to the error
Fields
status: ob_status< Describe the status code of the error, as compatible with previous customer status code requirements
message: [c_char; 256]< Describe the detailed error log
function: [c_char; 256]< Describe the name of the function where the error occurred
args: [c_char; 256]< Describes the parameters passed to the function when an error occurs. Used to check whether the parameter is wrong
exception_type: ob_exception_type< The description is the specific error type of the SDK