ob_multi_device_sync_config

Struct ob_multi_device_sync_config 

#[repr(C, packed(1))]
pub struct ob_multi_device_sync_config { pub syncMode: OBMultiDeviceSyncMode, pub depthDelayUs: c_int, pub colorDelayUs: c_int, pub trigger2ImageDelayUs: c_int, pub triggerOutEnable: bool, pub triggerOutDelayUs: c_int, pub framesPerTrigger: c_int, }
@brief The synchronization configuration of the device.

Fields

syncMode: OBMultiDeviceSyncMode

@brief The sync mode of the device.

depthDelayUs: c_int

@brief The delay time of the depth image capture after receiving the capture command or trigger signal in microseconds.

@attention This parameter is only valid for some models, please refer to the product manual for details.

colorDelayUs: c_int

@brief The delay time of the color image capture after receiving the capture command or trigger signal in microseconds.

@attention This parameter is only valid for some models, please refer to the product manual for details.

trigger2ImageDelayUs: c_int

@brief The delay time of the image capture after receiving the capture command or trigger signal in microseconds. @brief The depth and color images are captured synchronously as the product design and can not change the delay between the depth and color images.

@attention For Orbbec Astra 2 device, this parameter is valid only when the @ref triggerOutDelayUs is set to 0. @attention This parameter is only valid for some models to replace @ref depthDelayUs and @ref colorDelayUs, please refer to the product manual for details.

triggerOutEnable: bool

@brief Trigger signal output enable flag. @brief After the trigger signal output is enabled, the trigger signal will be output when the capture command or trigger signal is received. User can adjust the delay time of the trigger signal output by @ref triggerOutDelayUs.

@attention For some models, the trigger signal output is always enabled and cannot be disabled. @attention If device is in the @ref OB_MULTI_DEVICE_SYNC_MODE_FREE_RUN or @ref OB_MULTI_DEVICE_SYNC_MODE_STANDALONE mode, the trigger signal output is always disabled. Set this parameter to true will not take effect.

triggerOutDelayUs: c_int

@brief The delay time of the trigger signal output after receiving the capture command or trigger signal in microseconds.

@attention For Orbbec Astra 2 device, only supported -1 and 0. -1 means the trigger signal output delay is automatically adjusted by the device, 0 means the trigger signal output is disabled.

framesPerTrigger: c_int

@brief The frame number of each stream after each trigger in triggering mode.

@attention This parameter is only valid when the triggering mode is set to @ref OB_MULTI_DEVICE_SYNC_MODE_HARDWARE_TRIGGERING or @ref OB_MULTI_DEVICE_SYNC_MODE_SOFTWARE_TRIGGERING. @attention The trigger frequency multiplied by the number of frames per trigger cannot exceed the maximum frame rate of the stream profile which is set when starting the stream.