OBDepthPrecisionLevel

Type Alias OBDepthPrecisionLevel 

pub type OBDepthPrecisionLevel = c_uint;
@brief Enumeration for depth precision levels @attention The depth precision level does not completely determine the depth unit and real precision, and the influence of the data packaging format needs to be considered. The specific unit can be obtained through getValueScale() of DepthFrame