OBDeviceTimestampResetConfig

Type Alias OBDeviceTimestampResetConfig 

pub type OBDeviceTimestampResetConfig = ob_device_timestamp_reset_config;
@brief The timestamp reset configuration of the device.

Aliased Type

#[repr(C, packed(1))]
pub struct OBDeviceTimestampResetConfig { pub enable: bool, pub timestamp_reset_delay_us: i32, pub timestamp_reset_signal_output_enable: bool, }

Fields

enable: bool

@brief Whether to enable the timestamp reset function. @brief If the timestamp reset function is enabled, the timer for calculating the timestamp for output frames will be reset to 0 when the timestamp reset command or timestamp reset signal is received, and one timestamp reset signal will be output via TIMER_SYNC_OUT pin on synchronization port by default. The timestamp reset signal is input via TIMER_SYNC_IN pin on the synchronization port.

@attention For some models, the timestamp reset function is always enabled and cannot be disabled.

timestamp_reset_delay_us: i32

@brief The delay time of executing the timestamp reset function after receiving the command or signal in microseconds.

timestamp_reset_signal_output_enable: bool

@brief the timestamp reset signal output enable flag.

@attention For some models, the timestamp reset signal output is always enabled and cannot be disabled.