pub type OBExceptionType = c_uint;Expand description
@brief The exception types in the SDK, through the exception type, you can easily determine the specific type of error. For detailed error API interface functions and error logs, please refer to the information of ob_error