OBHdrConfig

Type Alias OBHdrConfig 

pub type OBHdrConfig = HDR_CONFIG;
@brief HDR Configuration

Aliased Type

#[repr(C, packed(1))]
pub struct OBHdrConfig { pub enable: u8, pub sequence_name: u8, pub exposure_1: u32, pub gain_1: u32, pub exposure_2: u32, pub gain_2: u32, }

Fields

enable: u8

@brief Enable/disable HDR, after enabling HDR, the exposure_1 and gain_1 will be used as the first exposure and gain, and the exposure_2 and gain_2 will be used as the second exposure and gain. The output image will be alternately exposed and gain between the first and second exposure and gain.

@attention After enabling HDR, the auto exposure will be disabled.

sequence_name: u8

< Sequence name

exposure_1: u32

< Exposure time 1

gain_1: u32

< Gain 1

exposure_2: u32

< Exposure time 2

gain_2: u32

< Gain 2