pub unsafe extern "C" fn ob_create_context(
error: *mut *mut ob_error,
) -> *mut ob_contextExpand description
@brief Create a context object with the default configuration file
@param[out] error Pointer to an error object that will be populated if an error occurs during context creation @return Pointer to the created context object