pub unsafe extern "C" fn ob_create_frame(
frame_type: ob_frame_type,
format: ob_format,
data_size: u32,
error: *mut *mut ob_error,
) -> *mut ob_frameExpand description
@brief Crate a frame object based on the specified parameters.
@attention The frame object is created with a reference count of 1, and the reference count should be decreased by calling @ref ob_delete_frame() when it is no longer needed.
@param frame_type The frame object type. @param format The frame object format. @param data_size The size of the frame object data. @param error Pointer to an error object that will be set if an error occurs. @return ob_frame* Return the frame object.