pub unsafe extern "C" fn ob_sensor_start(
sensor: *mut ob_sensor,
profile: *const ob_stream_profile,
callback: ob_frame_callback,
user_data: *mut c_void,
error: *mut *mut ob_error,
)Expand description
@brief Open the current sensor and set the callback data frame.
@param[in] sensor The sensor object. @param[in] profile The stream configuration information. @param[in] callback The callback function triggered when frame data arrives. @param[in] user_data Any user data to pass in and get from the callback. @param[out] error Logs error messages.