pub unsafe extern "C" fn ob_set_device_changed_callback(
context: *mut ob_context,
callback: ob_device_changed_callback,
user_data: *mut c_void,
error: *mut *mut ob_error,
)Expand description
@brief Set a device plug-in callback function @attention The added and removed device lists returned through the callback interface need to be released manually @attention This function supports multiple callbacks. Each call to this function adds a new callback to an internal list.
@param[in] context Pointer to the context object @param[in] callback Pointer to the callback function triggered when a device is plugged or unplugged @param[in] user_data Pointer to user data that can be passed to and retrieved from the callback function @param[out] error Pointer to an error object that will be populated if an error occurs during callback function setting