#[repr(C, packed(1))]pub struct OBDeviceSyncConfig {
pub syncMode: OBSyncMode,
pub irTriggerSignalInDelay: u16,
pub rgbTriggerSignalInDelay: u16,
pub deviceTriggerSignalOutDelay: u16,
pub deviceTriggerSignalOutPolarity: u16,
pub mcuTriggerFrequency: u16,
pub deviceId: u16,
}Expand description
@brief Device synchronization configuration @deprecated This structure is deprecated, please use @ref ob_multi_device_sync_config instead
Fields
syncMode: OBSyncMode@brief Device synchronize mode
irTriggerSignalInDelay: u16@brief IR Trigger signal input delay: Used to configure the delay between the IR/Depth/TOF Sensor receiving the trigger signal and starting exposure, Unit: microsecond
@attention This parameter is invalid when the synchronization MODE is set to @ref OB_SYNC_MODE_PRIMARY_IR_TRIGGER
rgbTriggerSignalInDelay: u16@brief RGB trigger signal input delay is used to configure the delay from the time when an RGB Sensor receives the trigger signal to the time when the exposure starts. Unit: microsecond
@attention This parameter is invalid when the synchronization MODE is set to @ref OB_SYNC_MODE_PRIMARY
deviceTriggerSignalOutDelay: u16@brief Device trigger signal output delay, used to control the delay configuration of the host device to output trigger signals or the slave device to output trigger signals. Unit: microsecond
@attention This parameter is invalid when the synchronization MODE is set to @ref OB_SYNC_MODE_CLOSE or @ref OB_SYNC_MODE_STANDALONE
deviceTriggerSignalOutPolarity: u16@brief The device trigger signal output polarity is used to control the polarity configuration of the trigger signal output from the host device or the trigger signal output from the slave device @brief 0: forward pulse; 1: negative pulse
@attention This parameter is invalid when the synchronization MODE is set to @ref OB_SYNC_MODE_CLOSE or @ref OB_SYNC_MODE_STANDALONE
mcuTriggerFrequency: u16@brief MCU trigger frequency, used to configure the output frequency of MCU trigger signal in MCU master mode, unit: Hz @brief This configuration will directly affect the image output frame rate of the Sensor. Unit: FPS (frames per second)
@attention This parameter is invalid only when the synchronization MODE is set to @ref OB_SYNC_MODE_PRIMARY_MCU_TRIGGER
deviceId: u16@brief Device number. Users can mark the device with this number